@@ -573,5 +573,8 @@ class GkeHubGrpcAsyncIOTransport(GkeHubTransport):
             )
         return self._stubs["generate_connect_manifest"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("GkeHubGrpcAsyncIOTransport",)
